selfDir_3d1bc249 := $(dir $(lastword $(MAKEFILE_LIST)))

vegxMaps := $(wildcard map.VegX.*.csv)
vegbienMaps := $(subst .VegX.,.VegBIEN.,$(vegxMaps))

table = $(shell s="$(*F)"; echo "$${s\#\#*.}")# remove sort order prefix

root := ../..
map := env out_database=vegbien $(root)/map

#####

all: _not_file # empty rule since must be first target in file

.SUFFIXES:

_not_file:
.PHONY: _not_file

all := $(wildcard output.*) $(vegbienMaps)

clean: _not_file
	$(RM) $(all)

#####

reinstall: _not_file uninstall install

#####

map.VegBIEN.%.csv: map.VegX.%.csv
	$(root)/bin/join_sort <$< $(root)/mappings/VegX-VegBIEN.$(table).csv >$@
.PRECIOUS: map.VegBIEN.%.csv

logs := $(wildcard *.log)

rm_logs: _not_file
	$(RM) $(logs)

#####

ifdef db

ifndef dbEngine
$(error dbEngine variable must be set. Possible values: MySQL, PostgreSQL)
endif

mapEnv := in_engine=$(dbEngine) in_database=$(db)

all: _not_file $(vegbienMaps:map.VegBIEN.%.csv=import-%)

log = $*$(if $(n),.n=$(n),).log

import-%: map.VegBIEN.%.csv _not_file
	$(importCmd)
importCmd = (set -x; "time" env commit=1 $(mapEnv) $(map) $<) \
$(if $(n),,>>$(log)) 2>&1 $(if $(n),| tee -a $(log))

##

install: _not_file db

uninstall: _not_file rm_db

bienPassword := $(shell cat $(root)/config/bien_password)
mysql := mysql --user=root --password='$(bienPassword)'

db: $(db).sql _not_file
	-$(mysql) <$<
	echo "GRANT SELECT ON $(db).* TO 'bien'@'localhost';"|$(mysql)
# ignore errors in db import so that GRANT will still be run

rm_db: _not_file
	-echo "REVOKE ALL ON $(db).* FROM 'bien'@'localhost';"|$(mysql)
	echo "DROP DATABASE IF EXISTS $(db);"|$(mysql)
# ignore errors if grant not defined

#####

else
$(error db variable must be set)
endif
